@@ -92,6 +92,22 @@ class Parameter(Base):
         return "{}-{} {}".format(self.store_id, self.lane_id, self.param_key)
 
 
+class TableSyncRule(Base):
+    """
+    Represents a "table sync rule" value.
+    """
+    __tablename__ = 'TableSyncRules'
+
+    id = sa.Column('tableSyncRuleID', sa.Integer(), nullable=False, primary_key=True, autoincrement=True)
+
+    table_name = sa.Column('tableName', sa.String(length=255), nullable=False, primary_key=True)
+
+    rule = sa.Column(sa.String(length=255), nullable=True)
+
+    def __str__(self):
+        return "{}: {}".format(self.table_name, self.rule)
+
+
 class Store(Base):
     """
     Represents a known store.
